pca9685

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2023 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PCA9685

type PCA9685 struct {
	PwmChannels []PwmChannel
	// contains filtered or unexported fields
}

func Initialize

func Initialize(busNr uint8, address uint8, frequency uint8) *PCA9685

Initializes the PCA board, use i2cdetect to find the address on the bus you are using by default, the address is 0x40 the suggested frequency is 50Hz (for servos)

type PwmChannel

type PwmChannel struct {
	// contains filtered or unexported fields
}

func (*PwmChannel) SetDutyCycle

func (ch *PwmChannel) SetDutyCycle(value uint16) error

type Register

type Register struct {
	// contains filtered or unexported fields
}

func (*Register) Read

func (reg *Register) Read() (int, error)

func (*Register) Write

func (reg *Register) Write(data []byte) error

Jump to